@@ -47,12 +47,13 @@ class StoppableWSGIServer(basehttp.WSGIServer):
 class TestServerThread(threading.Thread):
     """Thread for running a http server while tests are running."""
 
-    def __init__(self, address, port):
+    def __init__(self, address, port, fixtures):
         self.address = address
         self.port = port
         self._stopevent = threading.Event()
         self.started = threading.Event()
         self.error = None
+        self.fixtures = fixtures
         super(TestServerThread, self).__init__()
 
     def run(self):
@@ -78,15 +79,26 @@ class TestServerThread(threading.Thread):
 
         # Must do database stuff in this new thread if database in memory.
         from django.conf import settings
-        if settings.DATABASE_ENGINE == 'sqlite3' \
-            and (not settings.TEST_DATABASE_NAME or settings.TEST_DATABASE_NAME == ':memory:'):
+        create_db = False
+        if hasattr(settings, 'DATABASES') and settings.DATABASES:
+            # Django > 1.2
+            if settings.DATABASES['default']['ENGINE'] == 'django.db.backends.sqlite3' or \
+                settings.DATABASES['default']['TEST_NAME']:
+                create_db = True
+        elif settings.DATABASE_ENGINE:
+            # Django < 1.2
+            if settings.DATABASE_ENGINE == 'sqlite3' and \
+                (not settings.TEST_DATABASE_NAME or settings.TEST_DATABASE_NAME == ':memory:'):
+                create_db = True
+            
+        if create_db:
             from django.db import connection
             db_name = connection.creation.create_test_db(0)
             # Import the fixture data into the test database.
             if hasattr(self, 'fixtures'):
                 # We have to use this slightly awkward syntax due to the fact
                 # that we're using *args and **kwargs together.
-                call_command('loaddata', *self.fixtures, **{'verbosity': 0})
+                call_command('loaddata', *self.fixtures, **{'verbosity': 1})
 
         # Loop until we get a stop event.
         while not self._stopevent.isSet():
@@ -99,17 +111,19 @@ class TestServerThread(threading.Thread):
         threading.Thread.join(self, timeout)
 
 
-def start_test_server(self, address='localhost', port=8000):
+def start_test_server(self, address='127.0.0.1', port=8000, fixtures=[]):
     """Creates a live test server object (instance of WSGIServer)."""
-    self.server_thread = TestServerThread(address, port)
+    self.server_thread = TestServerThread(address, port, fixtures=fixtures)
     self.server_thread.start()
     self.server_thread.started.wait()
     if self.server_thread.error:
         raise self.server_thread.error
+start_test_server.__test__ = False   # Tell nose this is not a method to test
 
 def stop_test_server(self):
     if self.server_thread:
         self.server_thread.join()
+stop_test_server.__test__ = False    # Tell nose this is not a method to test
 
 ## New Code
         
@@ -120,9 +134,10 @@ from windmill.authoring import unit
 
 class WindmillDjangoUnitTest(TestCase, unit.WindmillUnitTestCase):
     test_port = 8000
+    fixtures = []
     def setUp(self):
-        self.start_test_server('localhost', self.test_port)
-        self.test_url = 'http://localhost:%d' % self.server_thread.port
+        self.start_test_server('127.0.0.1', self.test_port, self.fixtures)
+        self.test_url = 'http://127.0.0.1:%d' % self.server_thread.port
         unit.WindmillUnitTestCase.setUp(self)
 
     def tearDown(self):
