@@ -18,10 +18,7 @@ import time
 import httplib, urllib, copy
 import xmlrpclib
 import sys
-try:
-    import json as simplejson
-except:
-    import simplejson
+from windmill.dep import json
 if not sys.version.startswith('2.4'):
     from urlparse import urlparse
 else:
@@ -60,7 +57,7 @@ class _Method(object):
             params = None
         request['params'] = params
         logger.debug('Created python request object %s' % str(request))
-        return self.call(simplejson.dumps(request))
+        return self.call(json.dumps(request))
         
     def __getattr__(self, name):
         return _Method(self.call, "%s.%s" % (self.name, name))
@@ -133,7 +130,7 @@ class ServerProxy(object):
         response = self.__transport.request(request)
         logger.debug('got response from __transport :: %s' % response)
         if type(response) is not int:
-            return simplejson.loads(response)
+            return json.loads(response)
         else:
             logger.error('Recieved status code %s' % response)
 
